"""Main product initializer
"""

from zope.i18nmessageid import MessageFactory
from GrailTact.GrailTact import config

from Products.Archetypes import atapi
from Products.CMFCore import utils

# Define a message factory for when this product is internationalised.
# This will be imported with the special name "_" in most modules. Strings
# like _(u"message") will then be extracted by i18n tools for translation.

GrailTactMessageFactory = MessageFactory('GrailTact.GrailTact')


def initialize(context):
    """Initializer called when used as a Zope 2 product.

    This is referenced from configure.zcml. Regstrations as a "Zope 2 product"
    is necessary for GenericSetup profiles to work, for example.

    Here, we call the Archetypes machinery to register our content types
    with Zope and the CMF.
    """

    # Retrieve the content types that have been registered with Archetypes
    # This happens when the content type is imported and the registerType()
    # call in the content type's module is invoked. Actually, this happens
    # during ZCML processing, but we do it here again to be explicit. Of
    # course, even if we import the module several times, it is only run
    # once.

    content_types, constructors, ftis = atapi.process_types(
        atapi.listTypes(config.PROJECTNAME),
        config.PROJECTNAME)

    # Now initialize all these content types. The initialization process takes
    # care of registering low-level Zope 2 factories, including the relevant
    # add-permission. These are listed in config.py. We use different
    # permissions for each content type to allow maximum flexibility of who
    # can add which content types, where. The roles are set up in rolemap.xml
    # in the GenericSetup profile.

    for atype, constructor in zip(content_types, constructors):
        utils.ContentInit('%s: %s' % (config.PROJECTNAME, atype.portal_type),
            content_types=(atype, ),
            permission='Add portal content',
            extra_constructors=(constructor,),
            ).initialize(context)



"""Definition of the Contact email address content type
"""

from zope.interface import implements

from Products.Archetypes import atapi
from Products.ATContentTypes.content import folder
from Products.ATContentTypes.content import schemata

# -*- Message Factory Imported Here -*-

from GrailTact.GrailTact.interfaces import IContactemailaddress
from GrailTact.GrailTact.config import PROJECTNAME

from VariousDisplayWidgets.VariousDisplayWidgets.widgets.Email import EmailWidget

ContactemailaddressSchema = folder.ATFolderSchema.copy() + atapi.Schema((

    atapi.StringField(
        name='email',
        required=1,
        searchable=1,
        default='',
        validators=('isEmail',),
        size=40,
        widget=EmailWidget()
    )

))

# Set storage on fields copied from ATFolderSchema, making sure
# they work well with the python bridge properties.

ContactemailaddressSchema['title'].storage = atapi.AnnotationStorage()
ContactemailaddressSchema['title'].widget.visible = {'edit' : 'invisible', 'view':'visible'}
ContactemailaddressSchema['description'].storage = atapi.AnnotationStorage()

schemata.finalizeATCTSchema(
    ContactemailaddressSchema,
    folderish=True,
    moveDiscussion=False
)

from MegamanicEdit.MegamanicEdit import MegamanicEditable, tools

from AccessControl import ClassSecurityInfo
from Globals import InitializeClass

class Contactemailaddress(folder.ATFolder, MegamanicEditable.MegamanicEditable):
    """ """
    implements(IContactemailaddress)

    meta_type = "Contactemailaddress"
    schema = ContactemailaddressSchema

    security = ClassSecurityInfo()
    
    title = atapi.ATFieldProperty('title')
    description = atapi.ATFieldProperty('description')

    # -*- Your ATSchema to Python Property Bridges Here ... -*-

    security.declarePublic('getMegamanicEditableFields')
    def getMegamanicEditableFields(self):
        """Returns names of the fields we can edit."""
        return ('email', 'description')

    security.declarePublic('validateMainField')
    def validateMainField(self, email=''):
        """Validates that the value given is acceptable."""
        return not self.schema['email'].validate(email, self)

    def Title(self):
        """Returns a proper title."""
        return 'Email address'

InitializeClass(Contactemailaddress)
atapi.registerType(Contactemailaddress, PROJECTNAME)
tools.setup(Contactemailaddress)



# -*- extra stuff goes here -*-
from contactworkplaceandworktitle import IContactworkplaceandworktitle
from contactphonenumber import IContactphonenumber
from contactemailaddress import IContactemailaddress
from contactnetaddress import IContactnetaddress
from contact import IContact



"""Definition of the Contact content type
"""

from zope.interface import implements

from Products.Archetypes import atapi
from Products.ATContentTypes.content import folder
from Products.ATContentTypes.content import schemata

# -*- Message Factory Imported Here -*-

#from GrailTact.GrailTact.interfaces import IContact
from GrailTact.GrailTact.config import PROJECTNAME

from MegamanicEdit.MegamanicEdit import MegamanicEditable, tools

ContactSchema = folder.ATFolderSchema.copy() + MegamanicEditable.templateObjectSchema.copy()
# Set storage on fields copied from ATFolderSchema, making sure
# they work well with the python bridge properties.

ContactSchema['title'].storage = atapi.AnnotationStorage()
ContactSchema['title'].widget._properties['label'] = 'Fullname'
ContactSchema['description'].storage = atapi.AnnotationStorage()

schemata.finalizeATCTSchema(
    ContactSchema,
    folderish=True,
    moveDiscussion=False
)

from AccessControl import ClassSecurityInfo
from Globals import InitializeClass

class Contactlandingpage(MegamanicEditable.MegamanicEditableTemplateObject, folder.ATFolder, ):
    """Description of the Example Type"""

    meta_type = "Contactlandingpage"
    schema = ContactSchema

    security = ClassSecurityInfo()

    title = atapi.ATFieldProperty('title')
    description = atapi.ATFieldProperty('description')

    # -*- Your ATSchema to Python Property Bridges Here ... -*-

    security.declarePublic('getMegamanicEditableFields')
    def getMegamanicEditableFields(self):
        """Returns names of the fields we can edit."""
        return ('title', 'description')

    security.declarePublic('getMegamanicEditableFields')
    def getMegamanicEditableFields(self):
        """Returns names of the fields we can edit."""
        return ('title', 'description', 'createContentType')

    security.declarePublic('anonymousAllowedToViewEditWidget')
    def anonymousAllowedToViewEditWidget(self):
        """Returns true if anonymous can add."""
        return self.getAllowAnonymousAdd()

InitializeClass(Contactlandingpage)
atapi.registerType(Contactlandingpage, PROJECTNAME)
tools.setup(Contactlandingpage)



"""Definition of the Contact workplace and work title content type
"""

from zope.interface import implements

from Products.Archetypes import atapi
from Products.ATContentTypes.content import folder
from Products.ATContentTypes.content import schemata

# -*- Message Factory Imported Here -*-

from GrailTact.GrailTact.interfaces import IContactworkplaceandworktitle
from GrailTact.GrailTact.config import PROJECTNAME

ContactworkplaceandworktitleSchema = folder.ATFolderSchema.copy() + atapi.Schema((

    atapi.StringField(
        name='employer',
        required=1,
        searchable=1,
        default='',
        validators=(),
        size=40,
    ),

    atapi.StringField(
        name='job_title',
        required=1,
        searchable=1,
        default='',
        validators=(),
        size=40,
    )

))

# Set storage on fields copied from ATFolderSchema, making sure
# they work well with the python bridge properties.

ContactworkplaceandworktitleSchema['title'].storage = atapi.AnnotationStorage()
ContactworkplaceandworktitleSchema['title'].widget.visible = {'edit' : 'invisible', 'view':'visible'}
ContactworkplaceandworktitleSchema['description'].storage = atapi.AnnotationStorage()

schemata.finalizeATCTSchema(
    ContactworkplaceandworktitleSchema,
    folderish=True,
    moveDiscussion=False
)

from MegamanicEdit.MegamanicEdit import MegamanicEditable, tools

from AccessControl import ClassSecurityInfo
from Globals import InitializeClass

class Contactworkplaceandworktitle(folder.ATFolder, MegamanicEditable.MegamanicEditable):
    """Description of the Example Type"""
    implements(IContactworkplaceandworktitle)

    meta_type = "Contactworkplaceandworktitle"
    schema = ContactworkplaceandworktitleSchema

    security = ClassSecurityInfo()

    title = atapi.ATFieldProperty('title')
    description = atapi.ATFieldProperty('description')

    # -*- Your ATSchema to Python Property Bridges Here ... -*-

    security.declarePublic('getMegamanicEditableFields')
    def getMegamanicEditableFields(self):
        """Returns names of the fields we can edit."""
        return ('employer', 'job_title', 'description')

    security.declarePublic('validateMainField')
    def validateMainField(self, employer='', job_title=''):
        """Validates that the value given is acceptable."""
        return (not self.schema['employer'].validate(employer, self)) and \
                (not self.schema['job_title'].validate(job_title, self))

    def Title(self):
        """Returns a proper title."""
        return 'Workplace and title'

InitializeClass(Contactworkplaceandworktitle)
atapi.registerType(Contactworkplaceandworktitle, PROJECTNAME)
tools.setup(Contactworkplaceandworktitle)



"""Definition of the Contact phone number content type
"""

from zope.interface import implements

from Products.Archetypes import atapi
from Products.ATContentTypes.content import folder
from Products.ATContentTypes.content import schemata

# -*- Message Factory Imported Here -*-

from GrailTact.GrailTact.interfaces import IContactphonenumber
from GrailTact.GrailTact.config import PROJECTNAME

ContactphonenumberSchema = folder.ATFolderSchema.copy() + atapi.Schema((

    atapi.StringField(
        name='phone',
        required=1,
        searchable=1,
        default='',
        validators=('isInternationalPhoneNumber',),
        size=40,
    )

))

# Set storage on fields copied from ATFolderSchema, making sure
# they work well with the python bridge properties.

ContactphonenumberSchema['title'].storage = atapi.AnnotationStorage()
ContactphonenumberSchema['title'].widget.visible = {'edit' : 'invisible', 'view':'visible'}
ContactphonenumberSchema['description'].storage = atapi.AnnotationStorage()


schemata.finalizeATCTSchema(
    ContactphonenumberSchema,
    folderish=True,
    moveDiscussion=False
)

from MegamanicEdit.MegamanicEdit import MegamanicEditable, tools

from AccessControl import ClassSecurityInfo
from Globals import InitializeClass

class Contactphonenumber(folder.ATFolder, MegamanicEditable.MegamanicEditable):
    """Description of the Example Type"""
    implements(IContactphonenumber)

    meta_type = "Contactphonenumber"
    schema = ContactphonenumberSchema

    security = ClassSecurityInfo()

    title = atapi.ATFieldProperty('title')
    description = atapi.ATFieldProperty('description')

    # -*- Your ATSchema to Python Property Bridges Here ... -*-

    security.declarePublic('getMegamanicEditableFields')
    def getMegamanicEditableFields(self):
        """Returns names of the fields we can edit."""
        return ('phone', 'description')

    security.declarePublic('validateMainField')
    def validateMainField(self, phone=''):
        """Validates that the value given is acceptable."""
        return not self.schema['phone'].validate(phone, self)

    def Title(self):
        """Returns a proper title."""
        return 'Phone number'

InitializeClass(Contactphonenumber)
atapi.registerType(Contactphonenumber, PROJECTNAME)
tools.setup(Contactphonenumber)



"""Definition of the Contact content type
"""

from zope.interface import implements

from Products.Archetypes import atapi
from Products.ATContentTypes.content import folder
from Products.ATContentTypes.content import schemata

# -*- Message Factory Imported Here -*-

from GrailTact.GrailTact.interfaces import IContact
from GrailTact.GrailTact.config import PROJECTNAME

ContactSchema = folder.ATFolderSchema.copy() + atapi.Schema((

))

# Set storage on fields copied from ATFolderSchema, making sure
# they work well with the python bridge properties.

ContactSchema['title'].storage = atapi.AnnotationStorage()
ContactSchema['title'].label = 'Fullname'
ContactSchema['title'].widget.label = 'Fullname'
ContactSchema['description'].storage = atapi.AnnotationStorage()

schemata.finalizeATCTSchema(
    ContactSchema,
    folderish=True,
    moveDiscussion=False
)

from MegamanicEdit.MegamanicEdit import MegamanicEditable, tools

from AccessControl import ClassSecurityInfo
from Globals import InitializeClass

class Contact(folder.ATFolder, MegamanicEditable.MegamanicEditable):
    """Description of the Example Type"""
    implements(IContact)

    meta_type = "Contact"
    schema = ContactSchema

    security = ClassSecurityInfo()

    title = atapi.ATFieldProperty('title')
    description = atapi.ATFieldProperty('description')

    # -*- Your ATSchema to Python Property Bridges Here ... -*-

    def manage_afterAdd(self, a, b):
        """Hook to add some default things."""
        pass
        # self.portal_types.constructContent('Contact email address', self, 'email_address')

    security.declarePublic('getMegamanicEditableFields')
    def getMegamanicEditableFields(self):
        """Returns names of the fields we can edit."""
        return ('title', 'description')

    def getEmailAddresses(self):
        """Returns the email adresses contained."""
        return filter(None, map(lambda x: x.getEmail(), self.objectValues('Contactemailaddress')))

InitializeClass(Contact)
atapi.registerType(Contact, PROJECTNAME)
tools.setup(Contact)



from zope.interface import Interface
# -*- Additional Imports Here -*-


class IContactworkplaceandworktitle(Interface):
    """Description of the Example Type"""

    # -*- schema definition goes here -*-
